@@ -1,6 +1,8 @@
 /****************************************************************************
  * apps/examples/foc/foc_motor_b16.c
  *
+ * SPDX-License-Identifier: Apache-2.0
+ *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.  The
@@ -121,11 +123,11 @@ static int foc_motor_align(FAR struct foc_motor_b16_s *motor, FAR bool *done)
           goto errout;
         }
 
-      PRINTF("Aling results:\n");
+      PRINTFV("Aling results:\n");
 #ifdef CONFIG_INDUSTRY_FOC_ALIGN_DIR
-      PRINTF("  dir    = %.2f\n", b16tof(final.dir));
+      PRINTFV("  dir    = %.2f\n", b16tof(final.dir));
 #endif
-      PRINTF("  offset = %.2f\n", b16tof(final.offset));
+      PRINTFV("  offset = %.2f\n", b16tof(final.offset));
 
       *done = true;
     }
@@ -581,6 +583,8 @@ errout:
   return ret;
 }
 
+#if defined(CONFIG_EXAMPLES_FOC_HAVE_OPENLOOP) || \
+    defined(CONFIG_EXAMPLES_FOC_VELOBS)
 /****************************************************************************
  * Name: foc_motor_vel_reset
  ****************************************************************************/
@@ -614,6 +618,7 @@ static int foc_motor_vel_reset(FAR struct foc_motor_b16_s *motor)
 #endif
   return ret;
 }
+#endif
 
 /****************************************************************************
  * Name: foc_motor_state
@@ -1071,6 +1076,7 @@ static int foc_motor_ang_get(FAR struct foc_motor_b16_s *motor)
 #ifdef CONFIG_EXAMPLES_FOC_HAVE_VEL
   ain.vel   = motor->vel.set;
 #endif
+  ain.state = &motor->foc_state;
   ain.angle = motor->angle_now;
   ain.dir   = motor->dir;
 
@@ -1125,6 +1131,14 @@ static int foc_motor_ang_get(FAR struct foc_motor_b16_s *motor)
   motor->angle_obs = aout.angle;
 #endif
 
+#ifndef CONFIG_EXAMPLES_FOC_HAVE_RUN
+  /* Dummy value when motor controller disabled */
+
+  UNUSED(ain);
+  aout.type  = FOC_ANGLE_TYPE_ELE;
+  aout.angle = 0;
+#endif
+
   /* Store electrical angle from sensor or observer */
 
   if (aout.type == FOC_ANGLE_TYPE_ELE)
@@ -1247,7 +1261,8 @@ static int foc_motor_vel_get(FAR struct foc_motor_b16_s *motor)
   /* Get motor electrical velocity now */
 
 #if defined(CONFIG_EXAMPLES_FOC_HAVE_OPENLOOP) && \
-    !defined(CONFIG_EXAMPLES_FOC_VELOBS)
+    !defined(CONFIG_EXAMPLES_FOC_VELOBS) ||       \
+    !defined(CONFIG_EXAMPLES_FOC_HAVE_RUN)
   /* No velocity feedback - assume that electical velocity is velocity set
    * in a open-loop contorller.
    */
@@ -1600,8 +1615,17 @@ int foc_motor_init(FAR struct foc_motor_b16_s *motor,
   ret = foc_routine_cfg_b16(&motor->align, &align_cfg);
   if (ret < 0)
     {
+#  ifndef CONFIG_EXAMPLES_FOC_RUN_DISABLE
       PRINTFV("ERROR: foc_routine_cfg_b16 failed %d!\n", ret);
       goto errout;
+#  else
+      /* When motor controller is disabled, most likely we don't care about
+       * align routine failure
+       */
+
+      PRINTFV("ignore align routine failure\n", ret);
+      ret = OK;
+#  endif
     }
 #endif
 
@@ -1634,8 +1658,17 @@ int foc_motor_init(FAR struct foc_motor_b16_s *motor,
   ret = foc_routine_cfg_b16(&motor->ident, &ident_cfg);
   if (ret < 0)
     {
+#  ifndef CONFIG_EXAMPLES_FOC_RUN_DISABLE
       PRINTFV("ERROR: foc_ident_cfg_b16 failed %d!\n", ret);
       goto errout;
+#  else
+      /* When motor controller is disabled, most likely we don't care about
+       * ident routine failure
+       */
+
+      PRINTFV("ident align routine failure\n", ret);
+      ret = OK;
+#  endif
     }
 #endif
 
@@ -1665,8 +1698,9 @@ int foc_motor_init(FAR struct foc_motor_b16_s *motor,
       motor->ctrl_state = FOC_CTRL_STATE_INIT;
     }
 
-#if defined(CONFIG_EXAMPLES_FOC_SENSORED) ||  \
-    defined(CONFIG_EXAMPLES_FOC_HAVE_RUN) ||  \
+#if defined(CONFIG_EXAMPLES_FOC_SENSORED)   || \
+    defined(CONFIG_EXAMPLES_FOC_HAVE_RUN)   || \
+    defined(CONFIG_EXAMPLES_FOC_HAVE_ALIGN) || \
     defined(CONFIG_EXAMPLES_FOC_HAVE_IDENT)
 errout:
 #endif
