@@ -1,6 +1,8 @@
 /****************************************************************************
  * apps/examples/foc/foc_motor_f32.c
  *
+ * SPDX-License-Identifier: Apache-2.0
+ *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.  The
@@ -121,11 +123,11 @@ static int foc_motor_align(FAR struct foc_motor_f32_s *motor, FAR bool *done)
           goto errout;
         }
 
-      PRINTF("Aling results:\n");
+      PRINTFV("Aling results:\n");
 #ifdef CONFIG_INDUSTRY_FOC_ALIGN_DIR
-      PRINTF("  dir    = %.2f\n", final.dir);
+      PRINTFV("  dir    = %.2f\n", final.dir);
 #endif
-      PRINTF("  offset = %.2f\n", final.offset);
+      PRINTFV("  offset = %.2f\n", final.offset);
 
       *done = true;
     }
@@ -559,6 +561,8 @@ errout:
   return ret;
 }
 
+#if defined(CONFIG_EXAMPLES_FOC_HAVE_OPENLOOP) || \
+    defined(CONFIG_EXAMPLES_FOC_VELOBS)
 /****************************************************************************
  * Name: foc_motor_vel_reset
  ****************************************************************************/
@@ -592,6 +596,7 @@ static int foc_motor_vel_reset(FAR struct foc_motor_f32_s *motor)
 #endif
   return ret;
 }
+#endif
 
 /****************************************************************************
  * Name: foc_motor_state
@@ -1108,6 +1113,14 @@ static int foc_motor_ang_get(FAR struct foc_motor_f32_s *motor)
   motor->angle_obs = aout.angle;
 #endif
 
+#ifndef CONFIG_EXAMPLES_FOC_HAVE_RUN
+  /* Dummy value when motor controller disabled */
+
+  UNUSED(ain);
+  aout.type  = FOC_ANGLE_TYPE_ELE;
+  aout.angle = 0.0f;
+#endif
+
   /* Store electrical angle from sensor or observer */
 
   if (aout.type == FOC_ANGLE_TYPE_ELE)
@@ -1233,7 +1246,8 @@ static int foc_motor_vel_get(FAR struct foc_motor_f32_s *motor)
   /* Get motor electrical velocity now */
 
 #if defined(CONFIG_EXAMPLES_FOC_HAVE_OPENLOOP) && \
-    !defined(CONFIG_EXAMPLES_FOC_VELOBS)
+    !defined(CONFIG_EXAMPLES_FOC_VELOBS) ||       \
+    !defined(CONFIG_EXAMPLES_FOC_HAVE_RUN)
   /* No velocity feedback - assume that electical velocity is
    * velocity set
    */
@@ -1588,8 +1602,17 @@ int foc_motor_init(FAR struct foc_motor_f32_s *motor,
   ret = foc_routine_cfg_f32(&motor->align, &align_cfg);
   if (ret < 0)
     {
+#  ifndef CONFIG_EXAMPLES_FOC_RUN_DISABLE
       PRINTFV("ERROR: foc_routine_cfg_f32 failed %d!\n", ret);
       goto errout;
+#  else
+      /* When motor controller is disabled, most likely we don't care about
+       * align routine failure
+       */
+
+      PRINTFV("ignore align routine failure\n", ret);
+      ret = OK;
+#  endif
     }
 #endif
 
@@ -1619,8 +1642,17 @@ int foc_motor_init(FAR struct foc_motor_f32_s *motor,
   ret = foc_routine_cfg_f32(&motor->ident, &ident_cfg);
   if (ret < 0)
     {
+#  ifndef CONFIG_EXAMPLES_FOC_RUN_DISABLE
       PRINTFV("ERROR: foc_ident_cfg_f32 failed %d!\n", ret);
       goto errout;
+#  else
+      /* When motor controller is disabled, most likely we don't care about
+       * ident routine failure
+       */
+
+      PRINTFV("ident align routine failure\n", ret);
+      ret = OK;
+#  endif
     }
 #endif
 
@@ -1655,8 +1687,9 @@ int foc_motor_init(FAR struct foc_motor_f32_s *motor,
       motor->ctrl_state = FOC_CTRL_STATE_INIT;
     }
 
-#if defined(CONFIG_EXAMPLES_FOC_SENSORED) ||  \
-    defined(CONFIG_EXAMPLES_FOC_HAVE_RUN) ||  \
+#if defined(CONFIG_EXAMPLES_FOC_SENSORED)   || \
+    defined(CONFIG_EXAMPLES_FOC_HAVE_RUN)   || \
+    defined(CONFIG_EXAMPLES_FOC_HAVE_ALIGN) || \
     defined(CONFIG_EXAMPLES_FOC_HAVE_IDENT)
 errout:
 #endif
@@ -1957,12 +1990,6 @@ int foc_motor_control(FAR struct foc_motor_f32_s *motor)
         {
           motor->foc_mode = FOC_HANDLER_MODE_IDLE;
 
-#ifndef CONFIG_EXAMPLES_FOC_HAVE_RUN
-          /* Terminate */
-
-          motor->ctrl_state += 1;
-#endif
-
           break;
         }
 
