@@ -37,15 +37,10 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#ifndef CONFIG_CL_MFRC522
-#  error "CONFIG_CL_MFRC522 is not defined in the configuration"
-#endif
-
 #ifndef CONFIG_EXAMPLES_RFID_READUID_DEVNAME
 #  define CONFIG_EXAMPLES_RFID_READUID_DEVNAME "/dev/rfid0"
 #endif
 
-
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
