@@ -1,6 +1,8 @@
 /****************************************************************************
  * apps/nshlib/nsh_netcmds.c
  *
+ * SPDX-License-Identifier: Apache-2.0
+ *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.  The
@@ -1326,7 +1328,7 @@ int cmd_arp(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
   /* Error exits */
 
 errout_cmdfaild:
-  if (ret == -ENOENT)
+  if (ret == -ENOENT || ret == -ENETUNREACH)
     {
       nsh_error(vtbl, g_fmtnosuch, argv[0], "ARP entry", argv[optind]);
     }
