@@ -2,6 +2,8 @@
 ############################################################################
 # apps/tools/mksymtab.sh
 #
+# SPDX-License-Identifier: Apache-2.0
+#
 # Licensed to the Apache Software Foundation (ASF) under one or more
 # contributor license agreements.  See the NOTICE file distributed with
 # this work for additional information regarding copyright ownership.  The
@@ -21,22 +23,45 @@
 
 export LC_ALL=C
 
-usage="Usage: $0 <imagedirpath> [symtabprefix [additionalsymbolspath]]"
+usage() {
+  if [ $# -ne 0 ]; then
+    echo "ERROR: $@"
+  fi
+  echo -e "\nUsage: $0 <imagedirpath> [symtabprefix] [-a additionalsymbolspath]"
+  exit 1
+}
 
 # Check for the required directory path
 
 dir=$1
 if [ -z "$dir" ]; then
-  echo "ERROR: Missing <imagedirpath>"
-  echo ""
-  echo $usage
-  exit 1
+  usage "Missing <imagedirpath>"
 fi
 
 # Get the symbol table prefix
 
-prefix=$2
-add_sym=$3
+if [ "x${2:0:1}" != "x-" ]; then
+  prefix=$2
+  OPTIND=3
+else
+  OPTIND=2
+fi
+
+# Parse remaining arguments
+
+while getopts a: opt; do
+  case $opt in
+    a)
+      addlist="${addlist[@]} $OPTARG"
+      ;;
+    \?)
+      usage
+  esac
+done
+
+if [ $OPTIND != $(($# + 1)) ]; then
+  usage "Arguments remaining: \"${@:$OPTIND}\""
+fi
 
 # Extract all of the undefined symbols from the ELF files and create a
 # list of sorted, unique undefined variable names.
@@ -60,17 +85,16 @@ if [ -z "$varlist" ]; then
   fi
 fi
 
-if [ "x$add_sym" != "x" ]; then
-  if [ -f $add_sym ]; then
-    varlist="${varlist}\n$(cat $add_sym | grep -v "^,.*")"
-  elif [ -d $add_sym ]; then
-    varlist="${varlist}\n$(find $add_sym -type f | xargs cat | grep -v "^,.*")"
+for addsym in ${addlist[@]}; do
+  if [ -f $addsym ]; then
+    varlist="${varlist}\n$(cat $addsym | grep -v "^,.*")"
+  elif [ -d $addsym ]; then
+    varlist="${varlist}\n$(find $addsym -type f | xargs cat | grep -v "^,.*")"
   else
-    echo $usage
-    exit 1
+    usage
   fi
   varlist=$(echo -e "${varlist}" | sort -u)
-fi
+done
 
 # Now output the symbol table as a structure in a C source file.  All
 # undefined symbols are declared as void* types.  If the toolchain does
@@ -92,6 +116,8 @@ if [ -z "$prefix" ]; then
   echo "const struct symtab_s CONFIG_EXECFUNCS_SYMTAB_ARRAY[] = "
   echo "#elif defined(CONFIG_NSH_SYMTAB)"
   echo "const struct symtab_s CONFIG_NSH_SYMTAB_ARRAYNAME[] = "
+  echo "#elif defined(CONFIG_MODLIB_HAVE_SYMTAB)"
+  echo "const struct symtab_s CONFIG_MODLIB_SYMTAB_ARRAY[] = "
   echo "#else"
   echo "const struct symtab_s dummy_symtab[] = "
   echo "#endif"
@@ -112,6 +138,8 @@ if [ -z "$prefix" ]; then
   echo "const int CONFIG_EXECFUNCS_NSYMBOLS_VAR = sizeof(CONFIG_EXECFUNCS_SYMTAB_ARRAY) / sizeof(struct symtab_s);"
   echo "#elif defined(CONFIG_NSH_SYMTAB)"
   echo "const int CONFIG_NSH_SYMTAB_COUNTNAME = sizeof(CONFIG_NSH_SYMTAB_ARRAYNAME) / sizeof(struct symtab_s);"
+  echo "#elif defined(CONFIG_MODLIB_HAVE_SYMTAB)"
+  echo "const int CONFIG_MODLIB_NSYMBOLS_VAR = sizeof(CONFIG_MODLIB_SYMTAB_ARRAY) / sizeof(struct symtab_s);"
   echo "#else"
   echo "const int dummy_nsymtabs = sizeof(dummy_symtab) / sizeof(struct symtab_s);"
   echo "#endif"
